@@ -71,7 +71,8 @@ def fetch_full_info() -> List[Tuple]:
     _create_today_table()
     _create_month_table()
     cur.execute(
-        "SELECT t.id, l.parent_id, t.name, tt1.today, tt2.month, tt0.total "
+        "SELECT t.id, l.parent_id, t.name, t.type, "
+        "tt1.today, tt2.month, tt0.total "
         "FROM tasks t "
         "LEFT OUTER JOIN tt0 "
         "ON t.id = tt0.task_id "
@@ -96,8 +97,8 @@ def add_session(task_id: int, date: str, time: int) -> None:
     conn.commit()
 
 
-def add_task(task: str, parent_id: int = 0) -> None:
-    cur.execute("INSERT INTO tasks (name) VALUES (?)", (task,))
+def add_task(task: str, parent_id: int, etype: str) -> None:
+    cur.execute("INSERT INTO tasks (name, type) VALUES (?, ?)", (task, etype))
     cur.execute("SELECT id from tasks WHERE id = (SELECT MAX(id) from tasks)")
     task_id = cur.fetchone()[0]
     cur.execute("INSERT INTO links VALUES (?, ?)", (task_id, parent_id))
@@ -123,9 +124,12 @@ def rename_task(id: int, new_name: str) -> None:
     conn.commit()
 
 
-def get_max_task_id() -> int:
-    cur.execute("SELECT MAX(id) from tasks")
-    return cur.fetchone()[0]
+def change_parent(task_id: int, new_parent_id: int) -> None:
+    cur.execute(
+        "UPDATE links SET parent_id = (?) WHERE task_id=(?)",
+        (new_parent_id, task_id),
+    )
+    conn.commit()
 
 
 conn = sqlite3.connect(os.path.join(USER_DATA_DIR, DB_NAME))
